@@ -86,7 +86,7 @@
 #define KCONFIGWIDGETS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KCONFIGWIDGETS_NO_DEPRECATED
-#  define KCONFIGWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54d00
+#  define KCONFIGWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54f00
 #endif
 #ifdef KCONFIGWIDGETS_NO_DEPRECATED_WARNINGS
 #  define KCONFIGWIDGETS_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KCONFIGWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KCONFIGWIDGETS_DEPRECATED_WARNINGS_SINCE KCONFIGWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KCONFIGWIDGETS_DEPRECATED_WARNINGS_SINCE 0x54d00
+#    define KCONFIGWIDGETS_DEPRECATED_WARNINGS_SINCE 0x54f00
 #  endif
 #endif
 
@@ -151,6 +151,12 @@
 #else
 #  define KCONFIGWIDGETS_DEPRECATED_VERSION_5_64(text)
 #endif
+
+#if KCONFIGWIDGETS_DEPRECATED_WARNINGS_SINCE >= 0x54e00
+#  define KCONFIGWIDGETS_DEPRECATED_VERSION_5_78(text) KCONFIGWIDGETS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KCONFIGWIDGETS_DEPRECATED_VERSION_5_78(text)
+#endif
 #define KCONFIGWIDGETS_DEPRECATED_VERSION_4(minor, text)      KCONFIGWIDGETS_DEPRECATED_VERSION_4_##minor(text)
 #define KCONFIGWIDGETS_DEPRECATED_VERSION_5(minor, text)      KCONFIGWIDGETS_DEPRECATED_VERSION_5_##minor(text)
 #define KCONFIGWIDGETS_DEPRECATED_VERSION(major, minor, text) KCONFIGWIDGETS_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
